/*
  a basic player
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */





#ifndef _PLAYER_H
#define _PLAYER_H


#include <qapp.h>
#include <qpushbt.h>
#include <qfont.h>
#include <qlayout.h>
#include <qradiobt.h>
#include <qbttngrp.h>
#include <qlistbox.h> 
#include <qmlined.h> 


#include <yafAmplifier/metaPlayer.h>

#include <devices/audioDeviceLinux.h>
#include <devices/multicastDevice.h>
#include <devices/realTimeAudioDevice.h>


#include <deviceWidgets/guiTimerDevice.h>
#include <deviceWidgets/guiDecoder.h>
#include <deviceWidgets/guiInfoDevice.h>



/*
  This example shows how you create a GUI for a metaplayer.
  The central point is the device tree in a metaPlayer. 
  A "good" Gui should allow to add/remove devices on the
  fly.

  The layout of the devices should be managed by a device-layout
  Manager. (This example makes a very bad layout and does
  not use a configurable, dynamic manager at all)
  A good gui can allow to drag the devices around on the
  screen, like you can drag the Menu in every KDE
  application out of the window.
  There is nothing wrong with it that the user drags a spectrum
  analyser to the bottom on the screen into the KPanel :-)


  A nice feature would be to have a visual toolbox
  of devices and then drag them in the guiPlayer. The
  gui Player connects them with the device tree
  and if the user want to remove/configure a device in the guiPlayer
  he can click on it (open pulldownMenu) and then select
  "remove/configure"

  There are various configure options. Eg for a spectrum analyser
  you can set the update interval. For a "write to wav" device
  the path/filename.
  For a l3encoder device much more options (quality, path,...)

  The dynamic aspect is very important. But this example
  only shows a static device tree.

  It would be a good idea to write a common interface for
  gui devices which support drag/drop/configure/remove/pulldown
  Menus. 


*/



class GuiPlayer : public QWidget , public MetaPlayer  {
  Q_OBJECT

  MulticastDevice* multicastDevice;
  AudioDevice* audioDevice;
  GuiTimerDevice* guiTimerDevice;
  GuiInfoDevice* guiInfoDevice;
  GuiDecoder* guiDecoder;
  

 public:
  GuiPlayer();
  ~GuiPlayer();

  void setGenericStreamProducer(GenericStreamProducer* aDecoder);

 protected:
  OutputDevice* getInternalDeviceTree();
  void buildGui();

  QBoxLayout * b;
  QPushButton *test;
  QPushButton *quit;
  QPushButton *confirm;
  QButtonGroup* bg;
  QRadioButton* b1;
  QRadioButton* b2;
  QRadioButton* b3;


};

#endif


  
